# Episode 07-worldview: Way up here.

**This episode shows how you can use a notebook to setup a simple dashboard to
monitor all of your Metaflow flows.**

#### Showcasing:
- The metaflow client API.

#### Before playing this episode:
1. ```python -m pip install notebook```
2. This tutorial requires access to compute and storage resources on AWS, which
   can be configured by 
   a. Following the instructions at 
      https://docs.metaflow.org/metaflow-on-aws/deploy-to-aws or
   b. Requesting a sandbox at 
      https://docs.metaflow.org/metaflow-on-aws/metaflow-sandbox

#### To play this episode:
1. ```cd metaflow-tutorials```
2. ```jupyter-notebook 07-worldview/worldview.ipynb```
3. Open 'worldview.ipynb' in your remote Sagemaker notebook
